==> versa-0.3.4.tar.gz: versa-0.3.4/tools/py/reader/rdfalite.py <==
'''
'''

import sys
import logging
import warnings
from itertools import *

#from versa.writer.rdfs import prep as statement_prep
from versa import I, VERSA_BASEIRI, ORIGIN, RELATIONSHIP, TARGET, ATTRIBUTES

from versa.reader import statement_prep, dumb_triples, rdfize, versalinks

from rdflib import URIRef, Literal
from rdflib import BNode

from amara3 import iri
from amara3.uxml import tree
from amara3.uxml.treeutil import *
from amara3.uxml import html5

RDF_NS = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#'
#SCHEMAORG_NS is proper name. Deprecate the other
SCHEMAORG_NS = SCHEMA_NS = 'http://schema.org/'
FOAF_NS = 'http://xmlns.com/foaf/0.1/'
DC_NS = 'http://purl.org/dc/terms/'
BFL_NS = 'http://bibfra.me/vocab/lite/'

DEFAULT_PREFIXES = {
    'rdf': RDF_NS,
    'schema': SCHEMA_NS,
    'foaf': FOAF_NS,
    'dc': DC_NS,
    'bf': BFL_NS,
}

logger = logging.getLogger('rdfalite')
verbose = True
if verbose:
    logger.setLevel(logging.DEBUG)

BNODE_ROOT = 'urn:amara-bnode:_'

def toversa(htmlsource, model, source_uri):
    '''
    >>> import urllib
    >>> from versa.reader import rdfalite
    >>> from versa.driver import memory
    >>> m = memory.connection()
    >>> burl = 'http://link.delawarelibrary.org/'
    >>> with urllib.request.urlopen(burl) as resourcefp: rdfalite.toversa(resourcefp.read(), m, burl)

    '''
    sink = versalinks(model)
    next(sink) #Prime the coroutine
    return parse(htmlsource, sink, source_uri)


def tordf(htmlsource, rdfgr, source_uri):
    '''

    '''
    sink = rdfize(rdfgr)
    next(sink) #Prime the coroutine
    return parse(htmlsource, sink, source_uri)


def parse(htmlsource, statement_sink, source_uri):
    '''

    '''
    root = html5.parse(htmlsource)

    g_bnode_counter = 1
    def do_parse(elem, resource, vocab=None, prop=None, prefixes=None):
        nonlocal g_bnode_counter
        prefixes = prefixes or DEFAULT_PREFIXES.copy()
        vocab = elem.xml_attributes.get('vocab', vocab)
        #element_satisfied = False
        if vocab:
            prefix = elem.xml_attributes.get('prefix')
            if prefix:
                logging.debug('{}'.format(prefix))
                prefix_bits = prefix.split()
                # a, b = tee(prefix.split())
                # next(b, None)
                # for p, ns in zip(a, b):
                #     p = p.strip().strip(':')
                #     ns = ns.strip()
                #     print((p, ns))
                #     #print(p, ns)
                #     prefixes[p] = ns
                for i, j in zip(range(0, len(prefix_bits), 2), range(1, len(prefix_bits), 2)):
                    p = prefix_bits[i].strip().strip(':')
                    ns = prefix_bits[j].strip()
                    #print(p, ns)
                    prefixes[p] = ns
            new_resource = elem.xml_attributes.get('resource')
            if new_resource:
                try:
                    resource = I(iri.absolutize(new_resource.lstrip('/'), source_uri))
                except ValueError:
                    warnings.warn('Invalid URL or anchor {} found in {}'.format(new_resource, source_uri))
                    new_resource = None

            typeof_list = elem.xml_attributes.get('typeof')
            if typeof_list:
                for typeof in typeof_list.split():
                    typeof = I(iri.absolutize(typeof.lstrip('/'), vocab))
                    statement_sink.send((new_resource or resource, RDF_NS + 'type', typeof))

            new_prop_list = elem.xml_attributes.get('property')
            new_value = None
            if new_prop_list:
                #FIXME: Should this only be when about is used?
                if typeof_list and not new_resource:
                    new_value = BNode()
                    #new_value = I(BNODE_ROOT + str(g_bnode_counter))
                    #g_bnode_counter += 1
                elif new_resource:
                    new_value = new_resource
                for new_prop in new_prop_list.split():
                    if new_prop == 'about':
                        continue
                    elif ':' in new_prop:
                        p, local = new_prop.split(':', 1)
                        if not p in prefixes:
                            #FIXME: Silent error for now
                            continue
                        prop = I(iri.absolutize(local.lstrip('/'), prefixes[p]))
                    else:
                        prop = I(iri.absolutize(new_prop.lstrip('/'), vocab))
                    value = new_value or elem.xml_attributes.get('content') or elem.xml_value
                    statement_sink.send((resource, prop, value))
                    #print((resource, prop, value))
                    logging.debug('{}'.format((resource, prop, value)))
                    #element_satisfied = True
            if new_value: resource = new_value
        for child in elem.xml_children:
            if isinstance(child, element):
                do_parse(child, resource, vocab=vocab, prop=prop, prefixes=prefixes)

    do_parse(root, source_uri)
    return

==> versa-0.3.6.tar.gz: versa-0.3.6/tools/py/reader/rdfalite.py <==
'''
'''

import sys
import logging
import warnings
from itertools import *

#from versa.writer.rdfs import prep as statement_prep
from versa import I, VERSA_BASEIRI, ORIGIN, RELATIONSHIP, TARGET, ATTRIBUTES

from versa.reader import statement_prep, dumb_triples, rdfize, versalinks

from rdflib import URIRef, Literal
from rdflib import BNode

from amara3 import iri
from amara3.uxml import tree
from amara3.uxml.treeutil import *
from amara3.uxml import html5

RDF_NS = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#'
#SCHEMAORG_NS is proper name. Deprecate the other
SCHEMAORG_NS = SCHEMA_NS = 'http://schema.org/'
FOAF_NS = 'http://xmlns.com/foaf/0.1/'
DC_NS = 'http://purl.org/dc/terms/'
BFL_NS = 'http://bibfra.me/vocab/lite/'

DEFAULT_PREFIXES = {
    'rdf': RDF_NS,
    'schema': SCHEMA_NS,
    'foaf': FOAF_NS,
    'dc': DC_NS,
    'bf': BFL_NS,
}

logger = logging.getLogger('rdfalite')
verbose = True
if verbose:
    logger.setLevel(logging.DEBUG)

BNODE_ROOT = 'urn:amara-bnode:_'

def toversa(htmlsource, model, source_uri):
    '''
    >>> import urllib
    >>> from versa.reader import rdfalite
    >>> from versa.driver import memory
    >>> m = memory.connection()
    >>> burl = 'http://link.delawarelibrary.org/'
    >>> with urllib.request.urlopen(burl) as resourcefp: rdfalite.toversa(resourcefp.read(), m, burl)

    '''
    sink = versalinks(model)
    next(sink) #Prime the coroutine
    return parse(htmlsource, sink, source_uri)


def tordf(htmlsource, rdfgr, source_uri):
    '''

    '''
    sink = rdfize(rdfgr)
    next(sink) #Prime the coroutine
    return parse(htmlsource, sink, source_uri)


def parse(htmlsource, statement_sink, source_uri):
    '''

    '''
    root = html5.parse(htmlsource)

    g_bnode_counter = 1
    def do_parse(elem, resource, vocab=None, prop=None, prefixes=None):
        nonlocal g_bnode_counter
        prefixes = prefixes or DEFAULT_PREFIXES.copy()
        vocab = elem.xml_attributes.get('vocab', vocab)
        #element_satisfied = False
        if vocab:
            prefix = elem.xml_attributes.get('prefix')
            if prefix:
                logging.debug('{}'.format(prefix))
                prefix_bits = prefix.split()
                # a, b = tee(prefix.split())
                # next(b, None)
                # for p, ns in zip(a, b):
                #     p = p.strip().strip(':')
                #     ns = ns.strip()
                #     print((p, ns))
                #     #print(p, ns)
                #     prefixes[p] = ns
                for i, j in zip(range(0, len(prefix_bits), 2), range(1, len(prefix_bits), 2)):
                    p = prefix_bits[i].strip().strip(':')
                    ns = prefix_bits[j].strip()
                    #print(p, ns)
                    prefixes[p] = ns
            new_resource = elem.xml_attributes.get('resource')
            if new_resource:
                try:
                    resource = new_resource = I(iri.absolutize(new_resource, source_uri))
                except ValueError:
                    warnings.warn('Invalid URL or anchor {} found in {}'.format(new_resource, source_uri))
                    new_resource = None

            typeof_list = elem.xml_attributes.get('typeof')
            if typeof_list:
                for typeof in typeof_list.split():
                    typeof = I(iri.absolutize(typeof, vocab))
                    statement_sink.send((new_resource or resource, RDF_NS + 'type', typeof))

            new_prop_list = elem.xml_attributes.get('property')
            new_value = None
            if new_prop_list:
                #FIXME: Should this only be when about is used?
                if typeof_list and not new_resource:
                    new_value = BNode()
                    #new_value = I(BNODE_ROOT + str(g_bnode_counter))
                    #g_bnode_counter += 1
                elif new_resource:
                    new_value = new_resource
                for new_prop in new_prop_list.split():
                    if new_prop == 'about':
                        continue
                    elif ':' in new_prop:
                        p, local = new_prop.split(':', 1)
                        if not p in prefixes:
                            #FIXME: Silent error for now
                            continue
                        prop = I(iri.absolutize(local, prefixes[p]))
                    else:
                        prop = I(iri.absolutize(new_prop, vocab))
                    value = new_value or elem.xml_attributes.get('content') or elem.xml_attributes.get('href') or elem.xml_attributes.get('src') or elem.xml_value
                    statement_sink.send((resource, prop, value))
                    #print((resource, prop, value))
                    logging.debug('{}'.format((resource, prop, value)))
                    #element_satisfied = True
            if new_value: resource = new_value
        for child in elem.xml_children:
            if isinstance(child, element):
                do_parse(child, resource, vocab=vocab, prop=prop, prefixes=prefixes)

    do_parse(root, source_uri)
    return
